@@ -1,19 +1,13 @@
-# -*- coding: utf-8 -*-
 from django.conf import settings
-from django.contrib.staticfiles.urls import staticfiles_urlpatterns
-
-__author__ = 'mikhailturilin'
-
-from django.conf.urls import *
+from django.urls import re_path
 from django.contrib import admin
-
+from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 
 admin.autodiscover()
 
-urlpatterns = patterns(
-    '',
-    url(r'^admin/', include(admin.site.urls)),
-)
+urlpatterns = [
+    re_path(r'^admin/', admin.site.urls),
+]
 
 if settings.DEBUG:
-    urlpatterns = staticfiles_urlpatterns() + urlpatterns
\ No newline at end of file
+    urlpatterns = staticfiles_urlpatterns() + urlpatterns
